==> SyL-0.9.0.tar.gz: SyL/include/framework/SyL_Filter.php <==
<?php
/**
 * -----------------------------------------------------------------------------
 *
 * SyL - Web Application Framework for PHP
 *
 * PHP version 4 (>= 4.3.x) or 5
 *
 * Copyright (C) 2006-2007 k.watanabe
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -----------------------------------------------------------------------------
 * @package   SyL
 * @author    k.watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2007 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: SyL_Filter.php,v 1.12 2007/02/17 14:28:09 seasonstream Exp $
 * @link      http://www.syl.jp/
 * -----------------------------------------------------------------------------
 */

/**
 * ե륿饹
 *
 * @package   SyL
 * @author    k.watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2007 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: SyL_Filter.php,v 1.12 2007/02/17 14:28:09 seasonstream Exp $
 * @link      http://www.syl.jp/
 **/
class SyL_Filter
{
    /**
     * ¹ե륿᥽å
     *
     * @access public
     * @param object ꥯȥ֥
     */
    function preAction(&$request)
    {
    }

    /**
     * ¹Ըե륿᥽å
     *
     * @access public
     * @param object ǡޥ͡㥪֥
     */
    function postAction(&$dm)
    {
    }

    /**
     * ե륿᥽å
     *
     * @access public
     * @param object ӥ塼֥
     */
    function preRender(&$view)
    {
    }

    /**
     * ϸե륿᥽å
     *
     * @access public
     */
    function postRender()
    {
    }

    /**
     * 쥯ȥ᥽å
     *
     * @access public
     */
    function trigger()
    {
        return null;
    }
}

?>

==> SyL-0.11.0.tar.gz: SyL/include/framework/SyL_Filter.php <==
<?php
/**
 * -----------------------------------------------------------------------------
 *
 * SyL - Web Application Framework for PHP
 *
 * PHP version 4 (>= 4.3.x) or 5
 *
 * Copyright (C) 2006-2007 k.watanabe
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -----------------------------------------------------------------------------
 * @package   SyL
 * @author    k.watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2007 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: SyL_Filter.php,v 1.13 2007/04/24 16:49:15 seasonstream Exp $
 * @link      http://www.syl.jp/
 * -----------------------------------------------------------------------------
 */

/**
 * ե륿饹
 *
 * @package   SyL
 * @author    k.watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2007 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: SyL_Filter.php,v 1.13 2007/04/24 16:49:15 seasonstream Exp $
 * @link      http://www.syl.jp/
 **/
class SyL_Filter
{
    /**
     * ¹ե륿᥽å
     *
     * @access public
     * @param object ꥯȥ֥
     */
    function preAction(&$data)
    {
    }

    /**
     * ¹Ըե륿᥽å
     *
     * @access public
     * @param object ǡޥ͡㥪֥
     */
    function postAction(&$data)
    {
    }

    /**
     * ե륿᥽å
     *
     * @access public
     * @param object ӥ塼֥
     */
    function preRender(&$view)
    {
    }

    /**
     * ϸե륿᥽å
     *
     * @access public
     */
    function postRender()
    {
    }

    /**
     * 󥿡ե᥽å
     *
     * @access public
     */
    function affect()
    {
        return null;
    }
}

?>
